Package 'myman'

Title: Draw From July 2026 Sequence of Posts by Kevin Kruse Starting with 'My Man'
Description: Starting on the afternoon of July 17, 2026, Kevin Kruse fired off an astonishing array of BlueSky replies to an initial post of his featuring a certain government figure: \url{https://bsky.app/profile/did:plc:cnpe7qvcyjrhm6w7w7e4atur/post/3mqum4mxsuk2g}. All posts start with "My man ..." and make for excellent input to a 'fortunes'-like package. So this small package obliges and offers a random draw each time its 'myman()' function is called. The overall package structure follows package `fortunes`, and `atrrr` was used to (bulk-)retrieve posts. Neither package is required to run this package to display random selections.
Authors: Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>)
Maintainer: Dirk Eddelbuettel <[email protected]>
License: GPL (>= 2)
Version: 0.0.1
Built: 2026-07-19 19:53:17 UTC
Source: https://github.com/eddelbuettel/myman

Help Index


Display a Random 'my man' Skeet by Kevin Kruse

Description

This function displays a randomly chosen line from the included data set of over three hundred thirty 'my man' skeets by Kevin Kruse posted on Bluesky during two days in July 2026 in replies to the initial post https://bsky.app/profile/did:plc:cnpe7qvcyjrhm6w7w7e4atur/post/3mqum4mxsuk2g.

Usage

myman(ind)

## S3 method for class 'myman'
print(x, width = NULL, ...)

Arguments

ind

Optional index of a quote; if missing a random value is sampled

x

Default object for print method

width

Optional column width parameter

...

Other optional arguments

Value

A character vector containing one randomly selected line from the included file. It is of class myman for which an S3 print method will be invoked.

Examples

set.seed(123)
myman()