| Type: | Package |
| Title: | Draw from Sequence of 'My Man' Posts by Kevin Kruse |
| Version: | 0.1.0 |
| Date: | 2026-09-16 |
| Description: | Starting on the afternoon of July 17, 2026, Kevin Kruse fired off an astonishing array of 'BlueSky' replies to an initial post of his featuring a certain government figure: https://bsky.app/profile/did:plc:cnpe7qvcyjrhm6w7w7e4atur/post/3mqum4mxsuk2g. This lasted a week and generated nearly seven hundred posts. A second wave started on August 12, 2026, with this post: https://bsky.app/profile/kevinmkruse.bsky.social/post/3mstvbjpagc2a. A third wave started on August 17, 2026, with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mtcpiw7gi22j. A fourth wave started on August 27, 2026, with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mu3pugs2yk2f. A fifth wave ran on August 30, 2026, beginning with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mudbzy5ksk25. A sixth wave started September 4, 2026, with https://bsky.app/profile/kevinmkruse.bsky.social/post/3muparqtdkk2w. A seventh wave started September 12, 2026, with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mvdol6xu5k2s. All of the over fourteen hundred posts from these series start with 'My man ...' and make for excellent input to a 'fortunes'-like package. So this small package obliges and offers a random draw each time its myman() function is called. The overall package structure follows package 'fortunes', and 'atrrr' was used to (bulk-)retrieve posts. Neither package is required to run this package to display random selections. |
| URL: | https://github.com/eddelbuettel/myman |
| BugReports: | https://github.com/eddelbuettel/myman/issues |
| License: | GPL-2 | GPL-3 [expanded from: GPL (≥ 2)] |
| Encoding: | UTF-8 |
| Depends: | R (≥ 4.1.0) |
| NeedsCompilation: | no |
| Packaged: | 2026-09-16 13:10:59 UTC; edd |
| Author: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <edd@debian.org> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-27 16:30:16 UTC |
Display a Random 'my man' Skeet by Kevin Kruse
Description
This function displays a randomly chosen line from the included data set of one thousand four hundred and ninety four 'my man' skeets by Kevin Kruse posted on Bluesky starting in July 2026 in replies to the initial post https://bsky.app/profile/did:plc:cnpe7qvcyjrhm6w7w7e4atur/post/3mqum4mxsuk2g, and in August 2026 starting with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mstvbjpagc2a as well as starting with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mtcpiw7gi22j, again starting with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mu3pugs2yk2f, and again starting with https://bsky.app/profile/kevinmkruse.bsky.social/post/3mudbzy5ksk25 as well as with https://bsky.app/profile/kevinmkruse.bsky.social/post/3muparqtdkk2w and https://bsky.app/profile/kevinmkruse.bsky.social/post/3mvdol6xu5k2s.
Usage
myman(ind, target)
## S3 method for class 'myman'
print(x, width = NULL, ...)
Arguments
ind |
Optional index of a quote, or character expression to be matched; if missing a random index value is sampled |
target |
Optional character value to describe target of posts, can be a part of the name as regular expression matching is used |
x |
Default object for |
width |
Optional column width parameter |
... |
Other optional arguments |
Value
A character vector containing one randomly selected line from the included file.
It is of class myman for which an S3 print method will be invoked.
Examples
set.seed(123)
myman(target="Miller") # random draw against first target
myman("maitre") # all posts mentioning a "maitre'd"